@@ -145,9 +145,11 @@ static void dmix_server_free(snd_pcm_direct_t *dmix)
 #elif defined(__x86_64__)
 #include "pcm_dmix_x86_64.c"
 #else
+#ifndef DOC_HIDDEN
 #define mix_select_callbacks(x)	generic_mix_select_callbacks(x)
 #define dmix_supported_format generic_dmix_supported_format
 #endif
+#endif
 
 static void mix_areas(snd_pcm_direct_t *dmix,
 		      const snd_pcm_channel_area_t *src_areas,
@@ -172,6 +174,10 @@ static void mix_areas(snd_pcm_direct_t *dmix,
 		sample_size = 4;
 		do_mix_areas = (mix_areas_t *)dmix->u.dmix.mix_areas_32;
 		break;
+	case SND_PCM_FORMAT_S24_LE:
+		sample_size = 4;
+		do_mix_areas = (mix_areas_t *)dmix->u.dmix.mix_areas_24;
+		break;
 	case SND_PCM_FORMAT_S24_3LE:
 		sample_size = 3;
 		do_mix_areas = (mix_areas_t *)dmix->u.dmix.mix_areas_24;
@@ -236,6 +242,10 @@ static void remix_areas(snd_pcm_direct_t *dmix,
 		sample_size = 4;
 		do_remix_areas = (mix_areas_t *)dmix->u.dmix.remix_areas_32;
 		break;
+	case SND_PCM_FORMAT_S24_LE:
+		sample_size = 4;
+		do_remix_areas = (mix_areas_t *)dmix->u.dmix.remix_areas_24;
+		break;
 	case SND_PCM_FORMAT_S24_3LE:
 		sample_size = 3;
 		do_remix_areas = (mix_areas_t *)dmix->u.dmix.remix_areas_24;
@@ -595,8 +605,8 @@ static int snd_pcm_dmix_drop(snd_pcm_t *pcm)
 	snd_pcm_direct_t *dmix = pcm->private_data;
 	if (dmix->state == SND_PCM_STATE_OPEN)
 		return -EBADFD;
-	snd_pcm_direct_timer_stop(dmix);
 	dmix->state = SND_PCM_STATE_SETUP;
+	snd_pcm_direct_timer_stop(dmix);
 	return 0;
 }
 
@@ -869,7 +879,7 @@ static void snd_pcm_dmix_dump(snd_pcm_t *pcm, snd_output_t *out)
 		snd_pcm_dump(dmix->spcm, out);
 }
 
-static snd_pcm_ops_t snd_pcm_dmix_ops = {
+static const snd_pcm_ops_t snd_pcm_dmix_ops = {
 	.close = snd_pcm_dmix_close,
 	.info = snd_pcm_direct_info,
 	.hw_refine = snd_pcm_direct_hw_refine,
@@ -884,7 +894,7 @@ static snd_pcm_ops_t snd_pcm_dmix_ops = {
 	.munmap = snd_pcm_direct_munmap,
 };
 
-static snd_pcm_fast_ops_t snd_pcm_dmix_fast_ops = {
+static const snd_pcm_fast_ops_t snd_pcm_dmix_fast_ops = {
 	.status = snd_pcm_dmix_status,
 	.state = snd_pcm_dmix_state,
 	.hwsync = snd_pcm_dmix_hwsync,
