@@ -350,7 +350,7 @@ static void snd_pcm_lfloat_dump(snd_pcm_t *pcm, snd_output_t *out)
 	snd_pcm_dump(lfloat->plug.gen.slave, out);
 }
 
-static snd_pcm_ops_t snd_pcm_lfloat_ops = {
+static const snd_pcm_ops_t snd_pcm_lfloat_ops = {
 	.close = snd_pcm_generic_close,
 	.info = snd_pcm_generic_info,
 	.hw_refine = snd_pcm_lfloat_hw_refine,
